function ys = pollag (x,y,xs,n)
%POLLAG Calcola il valore del polinomio interpolatore
%       in un punto con Lagrange
%
% ys = pollag(x,y,xs,n,m)
%
% Variabili INGRESSO:
%     x       vettore contenente i nodi (1:n+1)
%     y       vettore contenente i valori della funzione nei 
%             nodi (1:n+1)
%     xs      valore di cui effettuare la valutazione
%     n       il numero dei nodi e' (n+1)
%
% Variabili USCITA:
%     ys      approssimazione calcolata

for i = 1:n+1;
	L(i)=1;
	for j = 1:i-1;
		L(i)=L(i) * (xs-x(j))/(x(i)-x(j));
	end;
	for j = i+1:n+1;
		L(i)=L(i) * (xs-x(j))/(x(i)-x(j));
	end;
end;
ys = 0;
for i = 1:n+1;
	ys = ys +y(i) * L(i);
end;

